<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="177"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Barvu změníte kliknutím.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Vyberte barvu</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Další (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Předchozí (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Hledat…</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Hledat pouze v názvech (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Hledat pouze ve štítcích (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Hledat ve všech uzlech (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Celé slovo (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Celé slovo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Rozlišovat malá/VELKÁ písmena (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Rozlišovat malá/VELKÁ písmena</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>&amp;Nedávno otevřené</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>For&amp;mát</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>S&amp;trom</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>M&amp;ožnosti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Najít:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Nahradit čím:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Má být nahrazeno</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Nahrazující text</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Předchozí (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Další (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Nahradit vše (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="692"/>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Zopakovat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Zopakovat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Najít</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Zobrazit/skrýt lištu hledání</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp;Odebrat veškeré formátování</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Odebrat veškeré formátování</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kurzíva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>&amp;Podtržení</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>&amp;Přeškrtnuté</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Přeškrtnuté</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>Barva te&amp;xtu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Barva textu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>&amp;Barva pozadí</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Barva pozadí</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;New Note</source>
        <translation>&amp;Nová poznámka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Uložit j&amp;ako</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>&amp;Tisk</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>&amp;Vytisknout s dílčími uzly</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>&amp;Nastavit heslo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="694"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>&amp;Vyjmout</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>Zk&amp;opírovat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>&amp;Vybrat vše</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>&amp;Zapouzdřit obrázek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4449"/>
        <source>Embed Image</source>
        <translation>Zapouzdřit obrázek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>&amp;Rozbalit vše</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>&amp;Sbalit vše</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Šipka nahoru</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>&amp;Připojit ty na stejné úrovni</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>&amp;Připojit podřízené</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Smazat uzel</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>Přesunout nahor&amp;u</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Šipka nahoru</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>&amp;Přesunout dolů</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Šipka dolů</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>Přejme&amp;novat uzel</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>Vlastn&amp;osti stromu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>&amp;Písmo dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>&amp;Zalomit řádky</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Automatické odsazování</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Předvolby</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>Najít a nah&amp;radit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>O &amp;aplikaci</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>Vyt&amp;isknout všechny uzly</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>&amp;Horní index</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Horní index</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>&amp;Horní index</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Dolní index</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>Vystř&amp;edit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Zarovnat na střed</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Šipka dolů</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2235"/>
        <source>&amp;Right</source>
        <translation>Vp&amp;ravo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Zarovnat vpravo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Šipka doprava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2229"/>
        <source>&amp;Left</source>
        <translation>V&amp;levo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Zarovnat doleva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Šipka doleva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>&amp;Vyrovnat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Vyrovnat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Šipka nahoru</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Předřadit příbuzné</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>Přesunout do&amp;leva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Šipka doleva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>Přesunout dop&amp;rava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Šipka doprava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>n&amp;2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Nadpis 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>n&amp;1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Nadpis 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>n&amp;3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Nadpis 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Písmo uzlu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Písmo uzlu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>Změn&amp;it měřítko obrázků</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>Vložit &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>Š&amp;títky</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Vložit od&amp;kaz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>Zk&amp;opírovat odkaz</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>&amp;Vložit tabulku</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Přidat řádek za</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Smazat řádek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Přidat sloupec za</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Smazat sloupec</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Sloučit buňky</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Vložit řádek před</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Vložit sloupec před</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Exportovat &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>&amp;Uložit obrázky</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Zprava doleva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Šipka doprava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Zleva doprava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Šipka doprava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Nabídka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>&amp;Ikona uzlu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Zkontrolovat pravopis</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>&amp;Barvy dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Vložit datum a čas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vyprázdnit</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3022"/>
        <source>Node Icon</source>
        <translation>Ikona uzlu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="676"/>
        <source>&amp;Raise/Hide</source>
        <translation>Vyzdvihnout/sk&amp;rýt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nová poznámka?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="929"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Opravdu chcete tento dokument opustit&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;a vytvořit nový prázdný?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2853"/>
        <location filename="../../fn.cpp" line="4812"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="933"/>
        <location filename="../../fn.cpp" line="2854"/>
        <location filename="../../fn.cpp" line="4813"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1024"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Uložit změny?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1026"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Dokument byl změněn.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1028"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Dokument byl odebrán.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <source>Discard changes</source>
        <translation>Zahodit změny</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1034"/>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="3065"/>
        <location filename="../../fn.cpp" line="3346"/>
        <location filename="../../fn.cpp" line="4388"/>
        <location filename="../../fn.cpp" line="4473"/>
        <location filename="../../fn.cpp" line="4651"/>
        <location filename="../../fn.cpp" line="4914"/>
        <location filename="../../fn.cpp" line="5867"/>
        <location filename="../../fn.cpp" line="6146"/>
        <location filename="../../fn.cpp" line="6244"/>
        <location filename="../../fn.cpp" line="6344"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1497"/>
        <source>Open file...</source>
        <translation>Otevřít soubor…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1674"/>
        <location filename="../../fn.cpp" line="5993"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Není možné uložit!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3642"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1774"/>
        <location filename="../../fn.cpp" line="1797"/>
        <source>Save As...</source>
        <translation>Uložit jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1499"/>
        <location filename="../../fn.cpp" line="1776"/>
        <location filename="../../fn.cpp" line="1799"/>
        <source>FeatherNotes documents</source>
        <translation>Dokumenty FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1499"/>
        <location filename="../../fn.cpp" line="1776"/>
        <location filename="../../fn.cpp" line="1799"/>
        <location filename="../../fn.cpp" line="3054"/>
        <location filename="../../fn.cpp" line="4572"/>
        <location filename="../../fn.cpp" line="4843"/>
        <source>All Files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2850"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Smazat tento uzel?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2851"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Varování!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Tuto akci nelze vzít zpět.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2957"/>
        <source>Tags</source>
        <translation>Štítky</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2972"/>
        <location filename="../../fn.cpp" line="3066"/>
        <location filename="../../fn.cpp" line="3347"/>
        <location filename="../../fn.cpp" line="4390"/>
        <location filename="../../fn.cpp" line="4474"/>
        <location filename="../../fn.cpp" line="4652"/>
        <location filename="../../fn.cpp" line="4915"/>
        <location filename="../../fn.cpp" line="5869"/>
        <location filename="../../fn.cpp" line="6147"/>
        <location filename="../../fn.cpp" line="6245"/>
        <location filename="../../fn.cpp" line="6345"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3054"/>
        <location filename="../../fn.cpp" line="4572"/>
        <location filename="../../fn.cpp" line="4843"/>
        <source>Image Files</source>
        <translation>Soubory s obrázky</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3154"/>
        <location filename="../../fn.cpp" line="3187"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Hlavní uzly:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Všechny uzly:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3160"/>
        <location filename="../../fn.cpp" line="3193"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Poznámka:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Hlavní uzly:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Všechny uzly:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3629"/>
        <source>%1 Matches</source>
        <translation>%1 shod</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3631"/>
        <source>One Match</source>
        <translation>Jedna shoda</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3633"/>
        <location filename="../../fn.cpp" line="4004"/>
        <source>No Match</source>
        <translation>Žádná shoda</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3799"/>
        <location filename="../../fn.cpp" line="3852"/>
        <source>Replacement</source>
        <translation>Nahrazení</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4111"/>
        <source>No Replacement</source>
        <translation>Žádné nahrazení</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4113"/>
        <source>One Replacement</source>
        <translation>Jedno nahrazení</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4116"/>
        <source>%1 Replacements</source>
        <translation>%1 nahrazení</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4376"/>
        <source>Insert Link</source>
        <translation>Vložit odkaz</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6090"/>
        <source>HTML Files</source>
        <translation>HTML soubory</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3030"/>
        <location filename="../../fn.cpp" line="4458"/>
        <source>Image path</source>
        <translation>Umístění obrázku</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3034"/>
        <location filename="../../fn.cpp" line="4462"/>
        <source>Open image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4470"/>
        <location filename="../../fn.cpp" line="4648"/>
        <source>Scaling percentage</source>
        <translation>Procento měřítka</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3052"/>
        <location filename="../../fn.cpp" line="4570"/>
        <source>Open Image...</source>
        <translation>Otevřít obrázek…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="653"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Oznamovací oblast systémového panelu není k dispozici.
Vypněte jeho využívání v Předvolbách.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="979"/>
        <source>New Node</source>
        <translation>Nový uzel</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1675"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nelze otevřít!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1756"/>
        <location filename="../../fn.cpp" line="5708"/>
        <location filename="../../fn.cpp" line="5717"/>
        <location filename="../../fn.cpp" line="5856"/>
        <location filename="../../fn.cpp" line="6047"/>
        <location filename="../../fn.cpp" line="6056"/>
        <location filename="../../fn.cpp" line="6083"/>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2228"/>
        <source>Align Table</source>
        <translation>Zarovnat tabulku</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2241"/>
        <source>&amp;Center</source>
        <translation>&amp;Na střed</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2680"/>
        <source>Select Text Color</source>
        <translation>Vybrat barvu textu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2712"/>
        <source>Select Background Color</source>
        <translation>Vybrat barvu pozadí</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2849"/>
        <source>Deletion</source>
        <translation>Smazání</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2967"/>
        <source>Tag(s) for this node</source>
        <translation>Štítky pro tento uzel</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3231"/>
        <source>Select Document Font</source>
        <translation>Vybrat písmo pro dokument</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3293"/>
        <source>Select Node Font</source>
        <translation>Vybrat písmo uzlu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3318"/>
        <source>Set Document Colors</source>
        <translation>Nastavit barvy dokumentu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3328"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Tyto barvy budou uplatněny na nové uzly.&lt;br&gt;Mohou a nemusí postihnout stávající uzly&lt;br&gt;ale je doporučeno znovuotevření dokumentu.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3331"/>
        <source>Background color:</source>
        <translation>Barva pozadí:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3337"/>
        <source>Text color:</source>
        <translation>Barva textu:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4121"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>Je zvýrazněno prvních 1000 nahrazení.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4465"/>
        <location filename="../../fn.cpp" line="4644"/>
        <source>Scale to</source>
        <translation>Změnit měřítko na</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4469"/>
        <location filename="../../fn.cpp" line="4647"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4638"/>
        <source>Scale Image(s)</source>
        <translation>Změnit měřítko obrázků</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4775"/>
        <source>untitled</source>
        <translation>bez názvu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4807"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4808"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Obrázek se nepodařilo uložit! Zkusit znovu?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4809"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Nejspíš jste nezvolili správnou příponu&lt;/center&gt;
&lt;center&gt;nebo nemáte oprávnění zapisovat do daného umístění.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4841"/>
        <source>Save Image As...</source>
        <translation>Uložit obrázek jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4896"/>
        <source>Insert Table</source>
        <translation>Vložit tabulku</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4902"/>
        <source>Rows:</source>
        <translation>Řádky:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4908"/>
        <source>Columns:</source>
        <translation>Sloupce:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5797"/>
        <source>Print Document</source>
        <translation>Vytisknout dokument</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5803"/>
        <source>Printing completed.</source>
        <translation>Tisk dokončen.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5805"/>
        <source>Printing in progress...</source>
        <translation>Tiskne se…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5824"/>
        <source>Export HTML</source>
        <translation>Exportovat HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5829"/>
        <source>Export:</source>
        <translation>Exportovat:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5830"/>
        <source>&amp;Current node</source>
        <translation>&amp;Stávající uzel</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5832"/>
        <source>With all &amp;sub-nodes</source>
        <translation>&amp;Se všemi dílčími uzly</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5833"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Všechny uzly</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5845"/>
        <source>Output file:</source>
        <translation>Výstupní soubor:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5864"/>
        <source>Select path</source>
        <translation>Vyberte umístění</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5905"/>
        <source>Question</source>
        <translation>Dotaz</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5906"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Soubor už existuje.
Chcete ho nahradit?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6088"/>
        <source>Save HTML As...</source>
        <translation>Uložit HTML jako…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6114"/>
        <source>Set Password</source>
        <translation>Nastavit heslo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6123"/>
        <source>Type password</source>
        <translation>Zadejte heslo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6135"/>
        <source>Retype password</source>
        <translation>Zopakujte zadání hesla</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6207"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Zadání hesla se neshodují. Zkuste to znovu!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6227"/>
        <location filename="../../fn.cpp" line="6235"/>
        <location filename="../../fn.cpp" line="6327"/>
        <location filename="../../fn.cpp" line="6335"/>
        <source>Enter Password</source>
        <translation>Zadejte heslo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6307"/>
        <location filename="../../fn.cpp" line="6341"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Nesprávné heslo. Zkuste to znovu!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6408"/>
        <source>A lightweight notes manager</source>
        <translation>Nenáročný správce poznámek</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6409"/>
        <source>based on Qt</source>
        <translation>založeno na Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6410"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6412"/>
        <location filename="../../fn.cpp" line="6413"/>
        <source>About FeatherNotes</source>
        <translation>O aplikaci FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6412"/>
        <source>Translators</source>
        <translation>Překladatelé</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6596"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Viz předvolby → Text → Kontrola pravopisu!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6612"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Je třeba přidat Hunspell slovník.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6617"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Hunspell slovník není k dispozici.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6625"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Hunspell slovník není doprovázen affix souborem.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6643"/>
        <location filename="../../fn.cpp" line="6658"/>
        <location filename="../../fn.cpp" line="6670"/>
        <source>No misspelling from text cursor.</source>
        <translation>Od pozice kurzoru dále nejsou žádné překlepy.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6682"/>
        <source>Spell Checking</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6411"/>
        <source>aka.</source>
        <translation>alias</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Text bez formátování (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Po zavření tohoto dialogu a také
při ukončení aplikace uloží velikost
okna.

Pokud chcete nastavit pevnou velikost, zrušte
zaškrtnutí!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>Zapamatovat si veliko&amp;st okna</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Začít s touto velikostí: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> obr. bodů</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Po zavření tohoto dialogu a také
při ukončení aplikace uloží šířku
stromu.

Pro výchozí poměr šířky 170/530
zrušte zaškrtnutí.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Zapamatovat si šířku s&amp;tromu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Uloží pozice po zavření
a také při ukončení tohoto dialogu.

To nemusí fungovat správně
s některými správci oken.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Uložit &amp;pozici</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Rozhoduje zda má být použita ikona v oznamovací
oblasti systémového panelu. Pokud je zaškrtnuto,
tlačítko zavřít na titulní liště okna ho namísto
ukončení aplikace zminimalizuje do právě do
oznamovací oblasti.

Aby se změna projevila, je třeba FeatherNotes
zavřít a spustit znovu.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Přidat do oznamovací oblasti s&amp;ystém. panelu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Namísto tohoto je možné použít
volbu příkazového řádku --tray</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Spouštět zminimalizované do oznamova&amp;cí oblasti</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Sloučit stromový pohled s jeho okolím?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Průhledný st&amp;romový pohled</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Ve výchozím stavu je velikost ikon na liště
nástrojů určována právě používaným stylem
ovládacích prvků.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Malé ikony na liště nástrojů</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Nezobrazovat lištu nástr&amp;ojů</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Pokud je lišta nástrojů skryta, na liště
nástrojů se objeví tlačítko nabídky.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Nezobrazovat lištu &amp;nabídky</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>&amp;Zalamovat řádky už ve výchozím stavu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>Automaticky odsazovat už ve výchozím stavu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Toto zahrnuje kulaté, složené a hranaté závorky a také uvozovky.

Aby se změna projevila, je třeba FeatherNotes ukončit a spustit znovu.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>Automatické uzavírání závorek</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Pokud vše funguje, jsou tři tečky jsou
nahrazeny výpustkou, dva spojovníky
pomlčkou, atd – zatímco uživatel píše.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>Nah&amp;razovat některé znaky v průběhu psaní</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Slouží pro vkládání data a času.
Pokud chcete použít systémový výchozí, nevyplňujte.

Uplatní se po zavření tohoto dialogu.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Formát data a času:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Automaticky uložit každých</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> minut</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Pokud je tato volba zaškrtnuta, otevřený dokument bude
při ukončování aplikace uložen bez dotazu a bez zobrazení
varování pokud ukládání není možné.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Při ukončování aplikace uložit otevřené dokumenty</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Hunspell slovník má název, který končí na „.dic“
a měl by být doprovázen affix souborem se stejným
názvem ale končící na „.aff“.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Popis umístění Hunspell slovníku:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>Přidat slovník…</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Soubory</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Začít naposledy otevřeným souborem</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Počet nedávných souborů:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Otevřít nedávné soubory samostatně</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Ve výchozím stavu jsou při otevírání dokumentu všechny uzly rozbaleny.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Pamatovat si stav rozbalení uzlů</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Varování: zjištěna opakující se zkratka!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Zadaná klávesová zkratka je vyhrazena pro něco jiného.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Aby se změny projevily, je třeba aplikaci restartovat.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Soubory s Hunspell slovníky</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Neznámé slovo:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Přidat do slovníku</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Nahradit čím:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Ignorovat tento výskyt</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Ignorovat vše</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Opravit tento výskyt</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Opravit vše</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>Nový uzel</translation>
    </message>
</context>
</TS>
